pub struct MobEffectDisplayState {
pub particles: ParticleList,
pub ambient: bool,
pub invisible: bool,
pub glowing: bool,
}Expand description
Synchronized living entity-data values derived from active mob effects.
Fields
particles: ParticleListVisible effect particles for LivingEntity.DATA_EFFECT_PARTICLES.
ambient: boolWhether all active effects are ambient.
invisible: boolWhether the shared invisible flag should be set by active effects.
glowing: boolWhether the shared glowing flag should be set by active effects.